rpc Package
===========

:mod:`client` Module
--------------------

.. automodule:: thriftpool.rpc.client
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`manager` Module
---------------------

.. automodule:: thriftpool.rpc.manager
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`transport` Module
-----------------------

.. automodule:: thriftpool.rpc.transport
    :members:
    :undoc-members:
    :show-inheritance:

